==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/registry/tag/RDItemTags.java <==
package cc.thonly.reverie_dreams.registry.tag;

import cc.thonly.reverie_dreams.ReverieDreams;
import net.minecraft.class_1792;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class RDItemTags {
    public static final class_6862<class_1792> EMPTY = of("empty");
    public static final class_6862<class_1792> FUMO = of("fumo");
    public static final class_6862<class_1792> ORB_BLOCK = of("orb");
    public static final class_6862<class_1792> ARMOR = of("armor");
    public static final class_6862<class_1792> SILVER_ARMOR = of("silver_armor");
    public static final class_6862<class_1792> SILVER_TOOL_MATERIALS = of("silver_tool_materials");
    public static final class_6862<class_1792> MAGIC_ICE_ARMOR = of("magic_ice_armor");
    public static final class_6862<class_1792> MAGIC_ICE_TOOL_MATERIALS = of("magic_ice_tool_materials");
    public static final class_6862<class_1792> DREAM_ARMOR = of("dream_ice_armor");
    public static final class_6862<class_1792> DREAM_TOOL_MATERIALS = of("dream_tool_materials");
    public static final class_6862<class_1792> MAID_ARMOR = of("maid_armor");
    public static final class_6862<class_1792> POWER_BLOCK = of("power_block");
    public static final class_6862<class_1792> POINT_BLOCK = of("point_block");
    public static final class_6862<class_1792> SILVER_BLOCK = of("silver_block");
    public static final class_6862<class_1792> PEACH = of("peach");
    public static final class_6862<class_1792> VAISRAVANAS_PAGODA = of("vaisravanas_pagoda_materials");
    public static final class_6862<class_1792> INGREDIENT_ITEM = of("ingredient_item");
    public static final class_6862<class_1792> FOOD_ITEM = of("food_item");
    public static final class_6862<class_1792> DRINK_ITEM = of("drink_item");
    public static final class_6862<class_1792> ROLE_TAME_FOOD = of("role_tame_food");
    public static final class_6862<class_1792> DANMAKU_ITEM = of("danmaku_item");
    public static final class_6862<class_1792> DLC0 = of("touhou_mystia_dlc/0");
    public static final class_6862<class_1792> DLC1 = of("touhou_mystia_dlc/1");
    public static final class_6862<class_1792> DLC2 = of("touhou_mystia_dlc/2");
    public static final class_6862<class_1792> DLC3 = of("touhou_mystia_dlc/3");
    public static final class_6862<class_1792> DLC4 = of("touhou_mystia_dlc/4");
    public static final class_6862<class_1792> DLC5 = of("touhou_mystia_dlc/5");
    public static final class_6862<class_1792> DLC6 = of("touhou_mystia_dlc/6");

    private static class_6862<class_1792> of(String id) {
        return class_6862.method_40092(class_7924.field_41197, ReverieDreams.id(id));
    }

    public static void register() {

    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/registry/tag/RDItemTags.java <==
package cc.thonly.reverie_dreams.registry.tag;

import cc.thonly.reverie_dreams.ReverieDreams;
import net.minecraft.class_1792;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class RDItemTags {
    public static final class_6862<class_1792> EMPTY = of("empty");
    public static final class_6862<class_1792> FUMO = of("fumo");
    public static final class_6862<class_1792> ORB_BLOCK = of("orb");
    public static final class_6862<class_1792> ARMOR = of("armor");
    public static final class_6862<class_1792> SILVER_ITEM = of("silver_item");
    public static final class_6862<class_1792> SILVER_ARMOR = of("silver_armor");
    public static final class_6862<class_1792> SILVER_TOOL_MATERIALS = of("silver_tool_materials");
    public static final class_6862<class_1792> MAGIC_ICE_ARMOR = of("magic_ice_armor");
    public static final class_6862<class_1792> MAGIC_ICE_TOOL_MATERIALS = of("magic_ice_tool_materials");
    public static final class_6862<class_1792> DREAM_ARMOR = of("dream_ice_armor");
    public static final class_6862<class_1792> DREAM_TOOL_MATERIALS = of("dream_tool_materials");
    public static final class_6862<class_1792> MAID_ARMOR = of("maid_armor");
    public static final class_6862<class_1792> POWER_BLOCK = of("power_block");
    public static final class_6862<class_1792> POINT_BLOCK = of("point_block");
    public static final class_6862<class_1792> SILVER_BLOCK = of("silver_block");
    public static final class_6862<class_1792> PEACH = of("peach");
    public static final class_6862<class_1792> VAISRAVANAS_PAGODA = of("vaisravanas_pagoda_materials");
    public static final class_6862<class_1792> INGREDIENT_ITEM = of("ingredient_item");
    public static final class_6862<class_1792> FOOD_ITEM = of("food_item");
    public static final class_6862<class_1792> DRINK_ITEM = of("drink_item");
    public static final class_6862<class_1792> ROLE_TAME_FOOD = of("role_tame_food");
    public static final class_6862<class_1792> DANMAKU_ITEM = of("danmaku_item");
    public static final class_6862<class_1792> REPLACEABLE_BLANK_PHOTOS = of("replaceable_blank_photos");
    public static final class_6862<class_1792> DLC0 = of("touhou_mystia_dlc/0");
    public static final class_6862<class_1792> DLC1 = of("touhou_mystia_dlc/1");
    public static final class_6862<class_1792> DLC2 = of("touhou_mystia_dlc/2");
    public static final class_6862<class_1792> DLC3 = of("touhou_mystia_dlc/3");
    public static final class_6862<class_1792> DLC4 = of("touhou_mystia_dlc/4");
    public static final class_6862<class_1792> DLC5 = of("touhou_mystia_dlc/5");
    public static final class_6862<class_1792> DLC6 = of("touhou_mystia_dlc/6");

    private static class_6862<class_1792> of(String id) {
        return class_6862.method_40092(class_7924.field_41197, ReverieDreams.id(id));
    }

    public static void register() {

    }
}
